package com.docus.server.collect.service;

import com.docus.core.util.Func;
import com.docus.server.sys.common.pojo.dto.DeptDTO;
import com.docus.server.sys.common.pojo.dto.UserDTO;
import com.docus.server.sys.service.IPowerDeptService;
import com.docus.server.sys.service.IPowerUserService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;

@Service
public class CollectService {
    protected final static String DEL_TYPE = "D";
    @Resource
    private IPowerDeptService deptService;
    @Resource
    private IPowerUserService userService;

    /**
     * 默认3次重试
     */
    /*@Async("recordMessage")
    @Retryable(value = Exception.class, maxAttempts = 3, backoff = @Backoff(delay = 2000L, multiplier = 1.5))*/
    @Transactional
    public void insertOrUpdateDept(DeptDTO deptDTO) {
        //异步写入归档系统，失败自动重试。
        if (checkType(deptDTO.getOperateType(), DEL_TYPE)) {
            deptService.delDeptByDeptCode(deptDTO.getDeptCode());
        } else {
            deptService.saveOrUpdatePowerDept(deptDTO);
        }
    }

    @Transactional
    public void insertOrUpdateUser(UserDTO userDTO) {
        // 判断操作类型
        if (checkType(userDTO.getOperateType(), DEL_TYPE)) {
            userService.delUserByUserName(userDTO.getUserName());
        } else {
            userService.saveOrUpdatePowerUser(userDTO);
        }
    }


    protected boolean checkType(String operateType, String delType) {
        return Func.isNotEmpty(operateType)
            && operateType.contains(delType);
    }
}
