package com.docus.server.ws.impl;

import com.docus.core.util.json.JSON;
import com.docus.log.annotation.TrackGroup;
import com.docus.log.context.TrackHelper;
import com.docus.server.record.pojo.dto.TBasicDTO;
import com.docus.server.record.service.ITBasicService;
import com.docus.server.visitor.VisitorProcessor;
import com.docus.server.ws.IBasicService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @author wen yongbin
 * @date 2023年2月25日21:56:33
 * @see com.docus.server.collect.infrastructure.dao.CollectTypeEnum 枚举
 * @see com.docus.server.ws.convert.IConverter 通用转化器
 * @see com.docus.server.ws.IWsResult 通用返回结果
 * @see VisitorProcessor 通用处理器
 */
@Service
@Slf4j
public class BasicServiceImpl implements IBasicService {
    @Resource
    private ITBasicService tBasicService;

    @Override
    @TrackGroup(
        group = "WEBSERVICE_XML_BASIC",
        beanNames = {"tBasicConverter", "wsBasicResultImpl"},
        processor = VisitorProcessor.class)
    public String setTBasic(String message) {
        log.info("新增基础数据：{}", message);
        tBasicService.insertTBasic(getValue());
        return null;
    }

    @Override
    @TrackGroup(
        group = "WEBSERVICE_XML_BASIC",
        beanNames = {"tBasicConverter", "wsBasicResultImpl"},
        processor = VisitorProcessor.class)
    public String updateTBasic(String message) {
        tBasicService.updateTBasic(getValue());
        return null;
    }

    public TBasicDTO getValue() {
        return JSON.fromJSON((String) TrackHelper.getValue("jsonStr"), TBasicDTO.class);
    }
}

