package com.docus.server.ws.impl;

import com.docus.core.util.json.JSON;
import com.docus.log.annotation.TrackGroup;
import com.docus.log.context.TrackHelper;
import com.docus.server.collect.service.CollectService;
import com.docus.server.sys.common.pojo.dto.UserDTO;
import com.docus.server.visitor.VisitorProcessor;
import com.docus.server.ws.IUserServer;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @author wen yongbin
 * @date 2023年2月25日21:56:33
 * @see com.docus.server.collect.infrastructure.dao.CollectTypeEnum 枚举
 * @see com.docus.server.ws.convert.IConverter 通用转化器
 * @see com.docus.server.ws.IWsResult 通用返回结果
 * @see VisitorProcessor 通用处理器
 */
@Service
@Slf4j
public class UserServerImpl implements IUserServer {
    @Resource
    private CollectService collectService;

    /**
     * 用户信息接收，进行操作
     *
     * @param message 接收到的用户参数
     * @return 返回结果
     */
    @Override
    @TrackGroup(
        group = "WEBSERVICE_XML_USER",
        beanNames = {"powerUserConverter", "wsUserResultImpl"},
        processor = VisitorProcessor.class)
    public String userModify(String message) {
        log.debug("新增/修改用户数据：{}", message);
        collectService.insertOrUpdateUser(JSON.fromJSON((String) TrackHelper.getValue("jsonStr"), UserDTO.class));
        return null;
    }

}

